==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/math1/maplib/mpfaza.c <==
/* src/math1/maplib/mpfaza.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     MAP PROJECTION (LANBERT AZIMUTHAL EQUAL-AREA)    93/02/20 S.SAKAI */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int mpfaza_0_(int n__, real *xlon, real *ylat, real *x, real 
	*y)
{
    /* Builtin functions */
    double sin(doublereal), cos(doublereal), sqrt(doublereal), atan2(
	    doublereal, doublereal), asin(doublereal);

    /* Local variables */
    static real r__, pi, th, rna;
    extern doublereal rfpi_(void);
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen);

    switch(n__) {
	case 1: goto L_mpiaza;
	}

    pi = rfpi_();
    th = pi / 2 - *ylat;
    if (th > pi) {
	th = pi;
    }
    if (th < 0.f) {
	th = 0.f;
    }
    r__ = sin(th / 2) * 2;
    *x = r__ * sin(*xlon);
    *y = -r__ * cos(*xlon);
    return 0;
/* ----------------------------------------------------------------------- */

L_mpiaza:
    pi = rfpi_();
    r__ = sqrt(*x * *x + *y * *y);
    if (r__ == 0.f) {
	*xlon = 0.f;
	*ylat = pi / 2.f;
	return 0;
    } else if (r__ <= 2.f) {
	*xlon = atan2(*x, -(*y));
	*ylat = pi / 2 - asin(r__ / 2) * 2;
	return 0;
    }
    glrget_("RUNDEF", &rna, (ftnlen)6);
    *xlon = rna;
    *ylat = rna;
    return 0;
} /* mpfaza_ */

/* Subroutine */ int mpfaza_(real *xlon, real *ylat, real *x, real *y)
{
    return mpfaza_0_(0, xlon, ylat, x, y);
    }

/* Subroutine */ int mpiaza_(real *x, real *y, real *xlon, real *ylat)
{
    return mpfaza_0_(1, xlon, ylat, x, y);
    }

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/math1/maplib/mpfaza.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     MAP PROJECTION (LANBERT AZIMUTHAL EQUAL-AREA)    93/02/20 S.SAKAI */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int mpfaza_0_(int n__, real *xlon, real *ylat, real *x, real 
	*y)
{
    /* Builtin functions */
    double sin(doublereal), cos(doublereal), sqrt(doublereal), atan2(
	    doublereal, doublereal), asin(doublereal);

    /* Local variables */
    static real r__, pi, th, rna;
    extern real rfpi_(void);
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen);

    switch(n__) {
	case 1: goto L_mpiaza;
	}

    pi = rfpi_();
    th = pi / 2 - *ylat;
    if (th > pi) {
	th = pi;
    }
    if (th < 0.f) {
	th = 0.f;
    }
    r__ = sin(th / 2) * 2;
    *x = r__ * sin(*xlon);
    *y = -r__ * cos(*xlon);
    return 0;
/* ----------------------------------------------------------------------- */

L_mpiaza:
    pi = rfpi_();
    r__ = sqrt(*x * *x + *y * *y);
    if (r__ == 0.f) {
	*xlon = 0.f;
	*ylat = pi / 2.f;
	return 0;
    } else if (r__ <= 2.f) {
	*xlon = atan2(*x, -(*y));
	*ylat = pi / 2 - asin(r__ / 2) * 2;
	return 0;
    }
    glrget_("RUNDEF", &rna, (ftnlen)6);
    *xlon = rna;
    *ylat = rna;
    return 0;
} /* mpfaza_ */

/* Subroutine */ int mpfaza_(real *xlon, real *ylat, real *x, real *y)
{
    return mpfaza_0_(0, xlon, ylat, x, y);
    }

/* Subroutine */ int mpiaza_(real *x, real *y, real *xlon, real *ylat)
{
    return mpfaza_0_(1, xlon, ylat, x, y);
    }
